@@ -14,7 +14,9 @@ def default(octiron: Octiron, iri: Node) -> str:
     descriptions = octiron.query(
         '''
         SELECT * WHERE {
-            ?page rdfs:label ?label .
+            OPTIONAL {
+                ?page rdfs:label ?label .
+            }
 
             OPTIONAL {
                 ?page octa:symbol ?symbol .
@@ -32,26 +34,31 @@ def default(octiron: Octiron, iri: Node) -> str:
         ''',
         page=iri,
     )
-    location = first(descriptions, None)
 
-    if not location:
-        raise PageNotFound(iri=iri)
+    try:
+        description = first(descriptions)
+    except ValueError:
+        return str(iri)
 
-    label = location['label']
-    symbol = location.get('symbol')
+    label = description.get('label', str(iri))
+    url = description.get('url')
 
-    if url := location.get('url'):
-        symbol = symbol or (
-            '📃' if location.get('is_page') else '🔗'
-        )
+    symbol = description.get('symbol')
+    if not symbol:
+        if description.get('is_page'):
+            symbol = '📃'
 
+        elif url:
+            symbol = '🔗'
+
+        else:
+            symbol = '[?]'
+
+    if url:
         return a(
-            f'{symbol} ',
+            symbol,
             label,
             href=url,
         )
 
-    if symbol:
-        return f'{symbol} {label}'
-
     return label
