@@ -10,6 +10,9 @@ from mkdocs.plugins import BasePlugin
 from mkdocs.structure.files import Files
 from mkdocs.structure.nav import Navigation
 from mkdocs.structure.pages import Page
+from rich.traceback import install
+from typing_extensions import TypedDict
+
 from octadocs.conversions import iri_by_page, src_path_to_iri
 from octadocs.default_context import construct_root_context
 from octadocs.iolanta import render
@@ -17,11 +20,9 @@ from octadocs.macros import link
 from octadocs.navigation.processor import OctadocsNavigationProcessor
 from octadocs.octiron import Octiron
 from octadocs.query import query
-from octadocs.storage import DiskCacheStorage
+from octadocs.storage import save_graph
 from octadocs.stored_query import StoredQuery
 from octadocs.types import LOCAL, Query, OCTA, DEFAULT_NAMESPACES
-from typing_extensions import TypedDict
-from rich.traceback import install
 
 install(show_locals=False)
 
@@ -151,10 +152,6 @@ class OctaDocsPlugin(BasePlugin):
                 named_contexts=config['extra']['named_contexts'],
             )
 
-        self.octiron.apply_inference()
-
-        DiskCacheStorage(octiron=self.octiron).save()
-
     def on_page_markdown(
         self,
         markdown: str,
@@ -240,6 +237,11 @@ class OctaDocsPlugin(BasePlugin):
         files: Files,
     ) -> Navigation:
         """Update the site's navigation from the knowledge graph."""
+        # This must run after all on_files() handlers of all plugins, but before
+        # any page rendering and facets. Nav calculation depends on inference,
+        # that's why we call it here in on_nav().
+        self.octiron.apply_inference()
+
         if not config.get('nav'):
             nav = OctadocsNavigationProcessor(
                 graph=self.octiron.graph,
@@ -265,3 +267,12 @@ class OctaDocsPlugin(BasePlugin):
                 server.watch(str(sparql_file), builder)
 
         return server
+
+    def on_post_build(self, config: Config):
+        """Save the graph to a file on disk."""
+        docs_dir = Path(config['docs_dir'])
+        save_graph(
+            graph=self.octiron.graph,
+            path=docs_dir.parent / '.cache/octadocs',
+        )
+        logger.info('Saved graph to disk for CLI to use.')
