@@ -3,6 +3,8 @@ from more_itertools import first
 from octadocs.octiron import Octiron
 from rdflib import URIRef
 
+from octadocs_adr.models import ADRNumberInvalid
+
 
 def link_to_adr(octiron: Octiron, iri: URIRef) -> a:
     """Link to an ADR document given by the IRI."""
@@ -13,7 +15,7 @@ def link_to_adr(octiron: Octiron, iri: URIRef) -> a:
                 octa:url ?url ;
                 octa:title ?label ;
                 adr:number ?number .
-            
+
             OPTIONAL {
                 ?page adr:status / octa:symbol ?symbol .
             }
@@ -27,6 +29,13 @@ def link_to_adr(octiron: Octiron, iri: URIRef) -> a:
         raise ValueError(f'Page not found by IRI: {iri}')
 
     number = location['number'].value
+
+    if not isinstance(number, int):
+        raise ADRNumberInvalid(
+            number=number,
+            page=iri,
+        )
+
     readable_number = f'ADR{number:03}'
 
     if symbol := location.get('symbol'):
